@@ -1,4 +1,4 @@
-`Chow.Denning` <-
+Chow.Denning <-
 function(y,kvec)
 {
     y <- as.matrix(y)
