@@ -1,4 +1,4 @@
-`Lo.Mac` <-
+Lo.Mac <-
 function(y,kvec)
 {
     y <- as.matrix(y)
@@ -10,6 +10,9 @@ function(y,kvec)
     LM <- LM_stat(y,k)
     mq[i,] <- cbind(LM$LM1,LM$LM2)
     }
-    return(list(Holding.Periods=kvec,M1.stat=mq[,1],M2.stat=mq[,2]))
+    VR <- mq
+    rownames(VR) <- paste("k=",kvec,sep="")
+    colnames(VR) <- c("M1","M2")
+    return(list(Stats=VR))
 }
 
